@@ -1,4 +1,5 @@
 from django.contrib.contenttypes.models import ContentType
+from django.forms import ValidationError as FormsValidationError
 from django.http import Http404
 from django.shortcuts import get_object_or_404
 from django_rq.queues import get_connection
@@ -12,7 +13,6 @@ from rest_framework.permissions import IsAuthenticated
 from rest_framework.response import Response
 from rest_framework.routers import APIRootView
 from rest_framework.viewsets import ReadOnlyModelViewSet, ViewSet
-from rq import Worker
 
 from nautobot.core.api.metadata import ContentTypeMetadata, StatusFieldMetadata
 from nautobot.core.api.views import ModelViewSet
@@ -40,7 +40,8 @@ from nautobot.extras.models import (
 )
 from nautobot.extras.models import CustomField, CustomFieldChoice
 from nautobot.extras.jobs import get_job, get_jobs, run_job
-from nautobot.utilities.exceptions import RQWorkerNotRunningException
+from nautobot.extras.utils import get_worker_count
+from nautobot.utilities.exceptions import CeleryWorkerNotRunningException
 from nautobot.utilities.utils import copy_safe_request, count_related
 from . import serializers
 
@@ -161,8 +162,8 @@ class GitRepositoryViewSet(CustomFieldModelViewSet):
         if not request.user.has_perm("extras.change_gitrepository"):
             raise PermissionDenied("This user does not have permission to make changes to Git repositories.")
 
-        if not Worker.count(get_connection("default")):
-            raise RQWorkerNotRunningException()
+        if not get_worker_count():
+            raise CeleryWorkerNotRunningException()
 
         repository = get_object_or_404(GitRepository, id=pk)
         enqueue_pull_git_repository_and_refresh_data(repository, request)
@@ -283,11 +284,22 @@ class JobViewSet(ViewSet):
         input_serializer = serializers.JobInputSerializer(data=request.data)
         input_serializer.is_valid(raise_exception=True)
 
-        data = input_serializer.data["data"]
+        data = input_serializer.data["data"] or {}
         commit = input_serializer.data["commit"]
         if commit is None:
             commit = getattr(job_class.Meta, "commit_default", True)
 
+        try:
+            job.validate_data(data)
+        except FormsValidationError as e:
+            # message_dict can only be accessed if ValidationError got a dict
+            # in the constructor (saved as error_dict). Otherwise we get a list
+            # of errors under messages
+            return Response({"errors": e.message_dict if hasattr(e, "error_dict") else e.messages}, status=400)
+
+        if not get_worker_count():
+            raise CeleryWorkerNotRunningException()
+
         job_content_type = ContentType.objects.get(app_label="extras", model="job")
 
         job_result = JobResult.enqueue_job(
@@ -434,11 +446,16 @@ class GraphQLQueryViewSet(ModelViewSet):
     serializer_class = serializers.GraphQLQuerySerializer
     filterset_class = filters.GraphQLQueryFilterSet
 
-    @swagger_auto_schema(method="post", request_body=serializers.GraphQLQuerySerializer)
+    @swagger_auto_schema(
+        method="post",
+        request_body=serializers.GraphQLQueryInputSerializer,
+        responses={"200": serializers.GraphQLQueryOutputSerializer},
+    )
     @action(detail=True, methods=["post"])
     def run(self, request, pk):
         try:
-            result = execute_saved_query(pk, variables=request.data, request=request).to_dict()
+            query = get_object_or_404(self.queryset, pk=pk)
+            result = execute_saved_query(query.slug, variables=request.data.get("variables"), request=request).to_dict()
             return Response(result)
         except GraphQLError as error:
             return Response(
