@@ -20,8 +20,10 @@ from django.db import transaction
 from django.db.models import Model
 from django.core.exceptions import ObjectDoesNotExist
 from django.db.models.query import QuerySet
+from django.forms import ValidationError
 from django.utils import timezone
 from django.utils.functional import classproperty
+import netaddr
 import yaml
 
 
@@ -321,6 +323,9 @@ class BaseJob:
             # FileVar (Save each FileVar as a FileProxy)
             elif isinstance(value, InMemoryUploadedFile):
                 return_data[field_name] = BaseJob.save_file(value)
+            # IPAddressVar, IPAddressWithMaskVar, IPNetworkVar
+            elif isinstance(value, netaddr.ip.BaseIP):
+                return_data[field_name] = str(value)
             # Everything else...
             else:
                 return_data[field_name] = value
@@ -343,7 +348,12 @@ class BaseJob:
         return_data = {}
 
         for field_name, value in data.items():
-            var = vars[field_name]
+            # If a field isn't a var, skip it (e.g. `_commit`).
+            try:
+                var = vars[field_name]
+            except KeyError:
+                continue
+
             if isinstance(var, MultiObjectVar):
                 queryset = var.field_attrs["queryset"].filter(pk__in=value)
                 if queryset.count() < len(value):
@@ -355,14 +365,38 @@ class BaseJob:
                 return_data[field_name] = var.field_attrs["queryset"].filter(pk__in=value)
 
             elif isinstance(var, ObjectVar):
-                return_data[field_name] = var.field_attrs["queryset"].get(pk=value)
+                if isinstance(value, dict):
+                    return_data[field_name] = var.field_attrs["queryset"].get(**value)
+                else:
+                    return_data[field_name] = var.field_attrs["queryset"].get(pk=value)
             elif isinstance(var, FileVar):
                 return_data[field_name] = cls.load_file(value)
+            # IPAddressVar is a netaddr.IPAddress object
+            elif isinstance(var, IPAddressVar):
+                return_data[field_name] = netaddr.IPAddress(value)
+            # IPAddressWithMaskVar, IPNetworkVar are netaddr.IPNetwork objects
+            elif isinstance(var, (IPAddressWithMaskVar, IPNetworkVar)):
+                return_data[field_name] = netaddr.IPNetwork(value)
             else:
                 return_data[field_name] = value
 
         return return_data
 
+    def validate_data(self, data):
+        vars = self._get_vars()
+
+        if not isinstance(data, dict):
+            raise ValidationError("Job data needs to be a dict")
+
+        for k, v in data.items():
+            if k not in vars:
+                raise ValidationError({k: "Job data contained an unknown property"})
+
+        # defer validation to the form object
+        f = self.as_form(data=data)
+        if not f.is_valid():
+            raise ValidationError(f.errors)
+
     @staticmethod
     def load_file(pk):
         """Load a file proxy stored in the database by primary key.
