@@ -12,6 +12,7 @@ from .models import (
     FileAttachment,
     FileProxy,
     GraphQLQuery,
+    HealthCheckTestModel,
     ImageAttachment,
     Job,
     JobResult,
@@ -34,6 +35,7 @@ __all__ = (
     "FileProxy",
     "GitRepository",
     "GraphQLQuery",
+    "HealthCheckTestModel",
     "ImageAttachment",
     "Job",
     "JobResult",
