@@ -62,7 +62,9 @@ class ComputedField(BaseModel, ChangeLoggedModel):
     description = models.CharField(max_length=200, blank=True)
     template = models.TextField(max_length=500, help_text="Jinja2 template code for field value")
     fallback_value = models.CharField(
-        max_length=500, help_text="Fallback value to be used for the field in the case of a template rendering error."
+        max_length=500,
+        blank=True,
+        help_text="Fallback value (if any) to be output for the field in the case of a template rendering error.",
     )
     weight = models.PositiveSmallIntegerField(default=100)
 
@@ -82,7 +84,14 @@ class ComputedField(BaseModel, ChangeLoggedModel):
 
     def render(self, context):
         try:
-            return render_jinja2(self.template, context)
+            rendered = render_jinja2(self.template, context)
+            # If there is an undefined variable within a template, it returns nothing
+            # Doesn't raise an exception either most likely due to using Undefined rather
+            # than StrictUndefined, but return fallback_value if None is returned
+            if rendered is None:
+                logger.warning("Failed to render computed field %s", self.slug)
+                return self.fallback_value
+            return rendered
         except Exception as exc:
             logger.warning("Failed to render computed field %s: %s", self.slug, exc)
             return self.fallback_value
