@@ -12,7 +12,6 @@ from django.urls import reverse
 from django.utils.timezone import make_aware
 from django_rq.queues import get_connection
 from rest_framework import status
-from rq import Worker
 
 from nautobot.dcim.models import (
     Device,
@@ -42,11 +41,12 @@ from nautobot.extras.models import (
     Tag,
     Webhook,
 )
-from nautobot.extras.jobs import Job, BooleanVar, IntegerVar, StringVar
+from nautobot.extras.jobs import Job, BooleanVar, IntegerVar, StringVar, ObjectVar
+from nautobot.extras.utils import get_worker_count
 from nautobot.utilities.testing import APITestCase, APIViewTestCases
 from nautobot.utilities.testing.utils import disable_warnings
 
-rq_worker_running = Worker.count(get_connection("default"))
+celery_worker_running = bool(get_worker_count())
 
 THIS_DIRECTORY = os.path.dirname(__file__)
 
@@ -211,24 +211,39 @@ class GitRepositoryTest(APIViewTestCases.APIViewTestCase):
         for repo in cls.repos:
             repo.save(trigger_resync=False)
 
-    @skipIf(not rq_worker_running, "RQ worker not running")
+    @skipIf(celery_worker_running, "Celery worker is running")
+    @override_settings(EXEMPT_VIEW_PERMISSIONS=[])
+    def test_run_git_sync_no_celery_worker(self):
+        """Git sync cannot be triggered if Celery is not running."""
+        self.add_permissions("extras.add_gitrepository")
+        self.add_permissions("extras.change_gitrepository")
+        url = reverse("extras-api:gitrepository-sync", kwargs={"pk": self.repos[0].id})
+        response = self.client.post(url, format="json", **self.header)
+        self.assertHttpStatus(response, status.HTTP_503_SERVICE_UNAVAILABLE)
+        self.assertEqual(response.data["detail"], "Unable to process request: Celery worker process not running.")
+
+    @skipIf(not celery_worker_running, "Celery worker not running")
     @override_settings(EXEMPT_VIEW_PERMISSIONS=[])
     def test_run_git_sync_nonexistent_repo(self):
+        """Git sync request handles case of a nonexistent repository."""
         self.add_permissions("extras.add_gitrepository")
+        self.add_permissions("extras.change_gitrepository")
         url = reverse("extras-api:gitrepository-sync", kwargs={"pk": "11111111-1111-1111-1111-111111111111"})
         response = self.client.post(url, format="json", **self.header)
         self.assertHttpStatus(response, status.HTTP_404_NOT_FOUND)
 
-    @skipIf(not rq_worker_running, "RQ worker not running")
+    @skipIf(not celery_worker_running, "Celery worker not running")
     @override_settings(EXEMPT_VIEW_PERMISSIONS=[])
     def test_run_git_sync_without_permissions(self):
+        """Git sync request verifies user permissions."""
         url = reverse("extras-api:gitrepository-sync", kwargs={"pk": self.repos[0].id})
         response = self.client.post(url, format="json", **self.header)
         self.assertHttpStatus(response, status.HTTP_403_FORBIDDEN)
 
-    @skipIf(not rq_worker_running, "RQ worker not running")
+    @skipIf(not celery_worker_running, "Celery worker not running")
     @override_settings(EXEMPT_VIEW_PERMISSIONS=[])
     def test_run_git_sync_with_permissions(self):
+        """Git sync request can run successfully."""
         self.add_permissions("extras.add_gitrepository")
         self.add_permissions("extras.change_gitrepository")
         url = reverse("extras-api:gitrepository-sync", kwargs={"pk": self.repos[0].id})
@@ -424,13 +439,15 @@ class JobTest(APITestCase):
             name = "Test job"
 
         var1 = StringVar()
-        var2 = IntegerVar()
+        var2 = IntegerVar(required=True)
         var3 = BooleanVar()
+        var4 = ObjectVar(model=DeviceRole)
 
         def run(self, data, commit=True):
-            self.log_info(message=data["var1"])
-            self.log_success(message=data["var2"])
-            self.log_failure(message=data["var3"])
+            self.log_debug(message=data["var1"])
+            self.log_info(message=data["var2"])
+            self.log_success(message=data["var3"])
+            self.log_warning(message=data["var4"])
 
             return "Job complete"
 
@@ -510,22 +527,48 @@ class JobTest(APITestCase):
         response = self.client.get(url, **self.header)
         self.assertHttpStatus(response, status.HTTP_404_NOT_FOUND)
 
-    @skipIf(not rq_worker_running, "RQ worker not running")
+    @skipIf(not celery_worker_running, "Celery worker not running")
     @override_settings(EXEMPT_VIEW_PERMISSIONS=[], JOBS_ROOT=THIS_DIRECTORY)
     def test_run_job_without_permission(self):
+        """Job run request enforces user permissions."""
         url = reverse("extras-api:job-run", kwargs={"class_path": "local/test_api/TestJob"})
         with disable_warnings("django.request"):
             response = self.client.post(url, {}, format="json", **self.header)
         self.assertHttpStatus(response, status.HTTP_403_FORBIDDEN)
 
-    @skipIf(not rq_worker_running, "RQ worker not running")
-    @override_settings(EXEMPT_VIEW_PERMISSIONS=[], JOBS_ROOT=THIS_DIRECTORY)
-    def test_run_job_with_permission(self):
+    @skipIf(celery_worker_running, "Celery worker is running")
+    def test_run_job_no_worker(self):
+        """Job run cannot be requested if Celery is not running."""
         self.add_permissions("extras.run_job")
+        device_role = DeviceRole.objects.create(name="role", slug="role")
         job_data = {
             "var1": "FooBar",
             "var2": 123,
             "var3": False,
+            "var4": device_role.pk,
+        }
+
+        data = {
+            "data": job_data,
+            "commit": True,
+        }
+
+        url = reverse("extras-api:job-run", kwargs={"class_path": "local/test_api/TestJob"})
+        response = self.client.post(url, data, format="json", **self.header)
+        self.assertHttpStatus(response, status.HTTP_503_SERVICE_UNAVAILABLE)
+        self.assertEqual(response.data["detail"], "Unable to process request: Celery worker process not running.")
+
+    @skipIf(not celery_worker_running, "Celery worker not running")
+    @override_settings(EXEMPT_VIEW_PERMISSIONS=["*"], JOBS_ROOT=THIS_DIRECTORY)
+    def test_run_job_object_var(self):
+        """Job run requests can reference objects by their primary keys."""
+        self.add_permissions("extras.run_job")
+        device_role = DeviceRole.objects.create(name="role", slug="role")
+        job_data = {
+            "var1": "FooBar",
+            "var2": 123,
+            "var3": False,
+            "var4": device_role.pk,
         }
 
         data = {
@@ -536,7 +579,84 @@ class JobTest(APITestCase):
         url = reverse("extras-api:job-run", kwargs={"class_path": "local/test_api/TestJob"})
         response = self.client.post(url, data, format="json", **self.header)
         self.assertHttpStatus(response, status.HTTP_200_OK)
-        self.assertEqual(response.data["result"]["status"]["value"], "pending")
+
+    # TODO: needs to be fixed - see https://github.com/nautobot/nautobot/issues/958
+    @skipIf(True, "Disabled due to issue #958")
+    @override_settings(EXEMPT_VIEW_PERMISSIONS=["*"], JOBS_ROOT=THIS_DIRECTORY)
+    def test_run_job_object_var_lookup(self):
+        """Job run requests can reference objects by their attributes."""
+        self.add_permissions("extras.run_job")
+        DeviceRole.objects.create(name="role", slug="role")
+        job_data = {
+            "var1": "FooBar",
+            "var2": 123,
+            "var3": False,
+            "var4": {"name": "role"},
+        }
+
+        data = {
+            "data": job_data,
+            "commit": True,
+        }
+
+        url = reverse("extras-api:job-run", kwargs={"class_path": "local/test_api/TestJob"})
+        response = self.client.post(url, data, format="json", **self.header)
+        self.assertHttpStatus(response, status.HTTP_200_OK)
+
+    @override_settings(EXEMPT_VIEW_PERMISSIONS=[], JOBS_ROOT=THIS_DIRECTORY)
+    def test_run_job_with_invalid_data(self):
+        self.add_permissions("extras.run_job")
+
+        data = {
+            "data": "invalid",
+            "commit": True,
+        }
+
+        url = reverse("extras-api:job-run", kwargs={"class_path": "local/test_api/TestJob"})
+        response = self.client.post(url, data, format="json", **self.header)
+        self.assertHttpStatus(response, status.HTTP_400_BAD_REQUEST)
+        self.assertEqual(response.data, {"errors": ["Job data needs to be a dict"]})
+
+    @override_settings(EXEMPT_VIEW_PERMISSIONS=[], JOBS_ROOT=THIS_DIRECTORY)
+    def test_run_job_with_wrong_data(self):
+        self.add_permissions("extras.run_job")
+        job_data = {
+            "var1": "FooBar",
+            "var2": 123,
+            "var3": False,
+            "var5": "wrong",
+        }
+
+        data = {
+            "data": job_data,
+            "commit": True,
+        }
+
+        url = reverse("extras-api:job-run", kwargs={"class_path": "local/test_api/TestJob"})
+        response = self.client.post(url, data, format="json", **self.header)
+        self.assertHttpStatus(response, status.HTTP_400_BAD_REQUEST)
+        self.assertEqual(response.data, {"errors": {"var5": ["Job data contained an unknown property"]}})
+
+    @override_settings(EXEMPT_VIEW_PERMISSIONS=[], JOBS_ROOT=THIS_DIRECTORY)
+    def test_run_job_with_missing_data(self):
+        self.add_permissions("extras.run_job")
+
+        job_data = {
+            "var1": "FooBar",
+            "var3": False,
+        }
+
+        data = {
+            "data": job_data,
+            "commit": True,
+        }
+
+        url = reverse("extras-api:job-run", kwargs={"class_path": "local/test_api/TestJob"})
+        response = self.client.post(url, data, format="json", **self.header)
+        self.assertHttpStatus(response, status.HTTP_400_BAD_REQUEST)
+        self.assertEqual(
+            response.data, {"errors": {"var2": ["This field is required."], "var4": ["This field is required."]}}
+        )
 
 
 class JobResultTest(APITestCase):
@@ -852,11 +972,11 @@ class GraphQLQueryTest(APIViewTestCases.APIViewTestCase):
 
     @classmethod
     def setUpTestData(cls):
-        graphqlqueries = (
+        cls.graphqlqueries = (
             GraphQLQuery(
                 name="graphql-query-1",
                 slug="graphql-query-1",
-                query="{ query: sites {name} }",
+                query="{ sites {name} }",
             ),
             GraphQLQuery(
                 name="graphql-query-2",
@@ -867,7 +987,7 @@ class GraphQLQueryTest(APIViewTestCases.APIViewTestCase):
                 name="graphql-query-3",
                 slug="graphql-query-3",
                 query="""
-query ($device: String!) {
+query ($device: [String!]) {
   devices(name: $device) {
     config_context
     name
@@ -958,10 +1078,26 @@ query ($device: String!) {
             ),
         )
 
-        for query in graphqlqueries:
+        for query in cls.graphqlqueries:
             query.full_clean()
             query.save()
 
+    def test_run_saved_query(self):
+        """Exercise the /run/ API endpoint."""
+        self.add_permissions("extras.add_graphqlquery")
+        self.add_permissions("extras.change_graphqlquery")
+        self.add_permissions("extras.view_graphqlquery")
+
+        url = reverse("extras-api:graphqlquery-run", kwargs={"pk": self.graphqlqueries[0].pk})
+        response = self.client.post(url, **self.header)
+        self.assertHttpStatus(response, status.HTTP_200_OK)
+        self.assertEqual({"data": {"sites": []}}, response.data)
+
+        url = reverse("extras-api:graphqlquery-run", kwargs={"pk": self.graphqlqueries[2].pk})
+        response = self.client.post(url, **self.header)
+        self.assertHttpStatus(response, status.HTTP_200_OK)
+        self.assertEqual({"data": {"devices": []}}, response.data)
+
 
 class RelationshipTest(APIViewTestCases.APIViewTestCase):
     model = Relationship
@@ -1143,7 +1279,6 @@ class ComputedFieldTest(APIViewTestCases.APIViewTestCase):
             "slug": "cf6",
             "label": "Computed Field 6",
             "template": "{{ obj.name }}",
-            "fallback_value": "error",
         },
     ]
     update_data = {
