@@ -1,15 +1,21 @@
+import json
+from io import StringIO
 import os
 import uuid
 
+from django.core.exceptions import ObjectDoesNotExist
 from django.core.files.uploadedfile import SimpleUploadedFile
+from django.core.management import call_command
+from django.core.management.base import CommandError
 from django.conf import settings
+from django.contrib.auth import get_user_model
 from django.contrib.contenttypes.models import ContentType
 
-from nautobot.dcim.models import Site
+from nautobot.dcim.models import DeviceRole, Site
 from nautobot.extras.choices import JobResultStatusChoices
 from nautobot.extras.jobs import get_job, run_job
-from nautobot.extras.models import FileAttachment, FileProxy, JobResult
-from nautobot.utilities.testing import TestCase
+from nautobot.extras.models import FileAttachment, FileProxy, JobResult, Status
+from nautobot.utilities.testing import CeleryTestCase, TestCase
 
 
 class JobTest(TestCase):
@@ -19,6 +25,10 @@ class JobTest(TestCase):
 
     maxDiff = None
 
+    @classmethod
+    def setUpTestData(cls):
+        cls.job_content_type = ContentType.objects.get(app_label="extras", model="job")
+
     def test_job_pass(self):
         """
         Job test with pass result.
@@ -28,11 +38,10 @@ class JobTest(TestCase):
             module = "test_pass"
             name = "TestPass"
             job_class = get_job(f"local/{module}/{name}")
-            job_content_type = ContentType.objects.get(app_label="extras", model="job")
 
             job_result = JobResult.objects.create(
                 name=job_class.class_path,
-                obj_type=job_content_type,
+                obj_type=self.job_content_type,
                 user=None,
                 job_id=uuid.uuid4(),
             )
@@ -50,10 +59,9 @@ class JobTest(TestCase):
             module = "test_fail"
             name = "TestFail"
             job_class = get_job(f"local/{module}/{name}")
-            job_content_type = ContentType.objects.get(app_label="extras", model="job")
             job_result = JobResult.objects.create(
                 name=job_class.class_path,
-                obj_type=job_content_type,
+                obj_type=self.job_content_type,
                 user=None,
                 job_id=uuid.uuid4(),
             )
@@ -120,11 +128,10 @@ class JobTest(TestCase):
             module = "test_read_only_pass"
             name = "TestReadOnlyPass"
             job_class = get_job(f"local/{module}/{name}")
-            job_content_type = ContentType.objects.get(app_label="extras", model="job")
 
             job_result = JobResult.objects.create(
                 name=job_class.class_path,
-                obj_type=job_content_type,
+                obj_type=self.job_content_type,
                 user=None,
                 job_id=uuid.uuid4(),
             )
@@ -143,10 +150,9 @@ class JobTest(TestCase):
             module = "test_read_only_fail"
             name = "TestReadOnlyFail"
             job_class = get_job(f"local/{module}/{name}")
-            job_content_type = ContentType.objects.get(app_label="extras", model="job")
             job_result = JobResult.objects.create(
                 name=job_class.class_path,
-                obj_type=job_content_type,
+                obj_type=self.job_content_type,
                 user=None,
                 job_id=uuid.uuid4(),
             )
@@ -178,6 +184,87 @@ class JobTest(TestCase):
 <br><span class="helptext">Hello</span><input id="id__commit" name="_commit" type="hidden" value="False"></td></tr>""",
             )
 
+    def test_ip_address_vars(self):
+        """
+        Test that IPAddress variable fields behave as expected.
+
+        This test case exercises the following types for both IPv4 and IPv6:
+
+        - IPAddressVar
+        - IPAddressWithMaskVar
+        - IPNetworkVar
+        """
+        with self.settings(JOBS_ROOT=os.path.join(settings.BASE_DIR, "extras/tests/dummy_jobs")):
+
+            module = "test_ipaddress_vars"
+            name = "TestIPAddresses"
+            job_class = get_job(f"local/{module}/{name}")
+
+            # Fill out the form
+            form_data = dict(
+                ipv4_address="1.2.3.4",
+                ipv4_with_mask="1.2.3.4/32",
+                ipv4_network="1.2.3.0/24",
+                ipv6_address="2001:db8::1",
+                ipv6_with_mask="2001:db8::1/64",
+                ipv6_network="2001:db8::/64",
+            )
+            form = job_class().as_form(form_data)
+            self.assertTrue(form.is_valid())
+
+            # Prepare the job data
+            job_result = JobResult.objects.create(
+                name=job_class.class_path,
+                obj_type=self.job_content_type,
+                user=None,
+                job_id=uuid.uuid4(),
+            )
+            data = job_class.serialize_data(form.cleaned_data)
+
+            # Run the job and extract the job payload data
+            run_job(data=data, request=None, commit=False, job_result_pk=job_result.pk)
+            job_result.refresh_from_db()
+            job_payload = job_result.data["run"]["log"][0][2]  # Indexing makes me sad.
+            job_result_data = json.loads(job_payload)
+
+            # Assert stuff
+            self.assertEqual(job_result.status, JobResultStatusChoices.STATUS_COMPLETED)
+            self.assertEqual(form_data, job_result_data)
+
+    def test_object_vars(self):
+        """
+        Test that Object variable fields behave as expected.
+        """
+        with self.settings(JOBS_ROOT=os.path.join(settings.BASE_DIR, "extras/tests/dummy_jobs")):
+
+            module = "test_object_vars"
+            name = "TestObjectVars"
+            job_class = get_job(f"local/{module}/{name}")
+
+            d = DeviceRole.objects.create(name="role", slug="role")
+
+            # Prepare the job data
+            job_result = JobResult.objects.create(
+                name=job_class.class_path,
+                obj_type=self.job_content_type,
+                user=None,
+                job_id=uuid.uuid4(),
+            )
+            data = {
+                "role": {"name": "role"},
+                "roles": [d.pk],
+            }
+
+            # Run the job and extract the job payload data
+            run_job(data=data, request=None, commit=False, job_result_pk=job_result.pk)
+            job_result.refresh_from_db()
+            job_payload = job_result.data["run"]["log"][0][2]  # Indexing makes me sad.
+            job_result_data = json.loads(job_payload)
+
+            # Assert stuff
+            self.assertEqual(job_result.status, JobResultStatusChoices.STATUS_COMPLETED)
+            self.assertEqual({"role": str(d.pk), "roles": [str(d.pk)]}, job_result_data)
+
 
 class JobFileUploadTest(TestCase):
     """Test a job that uploads/deletes files."""
@@ -196,7 +283,6 @@ class JobFileUploadTest(TestCase):
         with self.settings(JOBS_ROOT=os.path.join(settings.BASE_DIR, "extras/tests/dummy_jobs")):
             job_name = "local/test_file_upload_pass/TestFileUploadPass"
             job_class = get_job(job_name)
-            job = job_class()
 
             job_result = JobResult.objects.create(
                 name=job_class.class_path,
@@ -207,7 +293,9 @@ class JobFileUploadTest(TestCase):
 
             # Serialize the file to FileProxy
             data = {"file": self.dummy_file}
-            serialized_data = job.serialize_data(data)
+            form = job_class().as_form(files=data)
+            self.assertTrue(form.is_valid())
+            serialized_data = job_class.serialize_data(form.cleaned_data)
 
             # Assert that the file was serialized to a FileProxy
             self.assertTrue(isinstance(serialized_data["file"], uuid.UUID))
@@ -231,7 +319,6 @@ class JobFileUploadTest(TestCase):
         with self.settings(JOBS_ROOT=os.path.join(settings.BASE_DIR, "extras/tests/dummy_jobs")):
             job_name = "local/test_file_upload_fail/TestFileUploadFail"
             job_class = get_job(job_name)
-            job = job_class()
 
             job_result = JobResult.objects.create(
                 name=job_class.class_path,
@@ -242,7 +329,9 @@ class JobFileUploadTest(TestCase):
 
             # Serialize the file to FileProxy
             data = {"file": self.dummy_file}
-            serialized_data = job.serialize_data(data)
+            form = job_class().as_form(files=data)
+            self.assertTrue(form.is_valid())
+            serialized_data = job_class.serialize_data(form.cleaned_data)
 
             # Assert that the file was serialized to a FileProxy
             self.assertTrue(isinstance(serialized_data["file"], uuid.UUID))
@@ -262,3 +351,73 @@ class JobFileUploadTest(TestCase):
 
             # Assert that FileProxy was cleaned up
             self.assertEqual(FileProxy.objects.count(), 0)
+
+
+class RunJobManagementCommandTest(CeleryTestCase):
+    """Test cases for the `nautobot-server runjob` management command."""
+
+    def run_command(self, *args):
+        out = StringIO()
+        err = StringIO()
+        call_command(
+            "runjob",
+            *args,
+            stdout=out,
+            stderr=err,
+        )
+
+        return (out.getvalue(), err.getvalue())
+
+    def test_runjob_nochange_successful(self):
+        """Basic success-path test for Jobs that don't modify the Nautobot database."""
+        with self.settings(JOBS_ROOT=os.path.join(settings.BASE_DIR, "extras/tests/dummy_jobs")):
+            out, err = self.run_command("local/test_pass/TestPass")
+            self.assertIn("Running local/test_pass/TestPass...", out)
+            self.assertIn("test_pass: 1 success, 1 info, 0 warning, 0 failure", out)
+            self.assertIn("info: Database changes have been reverted automatically.", out)
+            self.assertIn("local/test_pass/TestPass: SUCCESS", out)
+            self.assertEqual("", err)
+
+    def test_runjob_db_change_no_commit(self):
+        """A job that changes the DB, when run with commit=False, doesn't modify the database."""
+        with self.assertRaises(ObjectDoesNotExist):
+            Status.objects.get(slug="test-status")
+
+        with self.settings(JOBS_ROOT=os.path.join(settings.BASE_DIR, "extras/tests/dummy_jobs")):
+            out, err = self.run_command("local/test_modify_db/TestModifyDB")
+            self.assertIn("Running local/test_modify_db/TestModifyDB...", out)
+            self.assertIn("test_modify_db: 0 success, 1 info, 0 warning, 0 failure", out)
+            self.assertIn("info: Database changes have been reverted automatically.", out)
+            self.assertIn("local/test_modify_db/TestModifyDB: SUCCESS", out)
+            self.assertEqual("", err)
+
+        with self.assertRaises(ObjectDoesNotExist):
+            Status.objects.get(slug="test-status")
+
+    def test_runjob_db_change_commit_no_username(self):
+        """A job that changes the DB, when run with commit=True but no username, is rejected."""
+        with self.settings(JOBS_ROOT=os.path.join(settings.BASE_DIR, "extras/tests/dummy_jobs")):
+            with self.assertRaises(CommandError):
+                self.run_command("--commit", "local/test_modify_db/TestModifyDB")
+
+    def test_runjob_db_change_commit_wrong_username(self):
+        """A job that changes the DB, when run with commit=True and a nonexistent username, is rejected."""
+        with self.settings(JOBS_ROOT=os.path.join(settings.BASE_DIR, "extras/tests/dummy_jobs")):
+            with self.assertRaises(CommandError):
+                self.run_command("--commit", "--username", "nosuchuser", "local/test_modify_db/TestModifyDB")
+
+    def test_runjob_db_change_commit_and_username(self):
+        """A job that chagnes the DB, when run with commit=True and a username, successfully updates the DB."""
+        with self.settings(JOBS_ROOT=os.path.join(settings.BASE_DIR, "extras/tests/dummy_jobs")):
+            get_user_model().objects.create(username="dummy_user")
+
+            out, err = self.run_command("--commit", "--username", "dummy_user", "local/test_modify_db/TestModifyDB")
+            self.assertIn("Running local/test_modify_db/TestModifyDB...", out)
+            self.assertIn("test_modify_db: 0 success, 0 info, 0 warning, 0 failure", out)
+            self.assertIn("local/test_modify_db/TestModifyDB: SUCCESS", out)
+            self.assertEqual("", err)
+
+        status = Status.objects.get(slug="test-status")
+        self.assertEqual(status.name, "Test Status")
+
+        status.delete()
